==> TundereBird-0.28.tar.bz2: TundereBird-0.28/gui/Smdn.Applications.TundereBird/Smdn.Applications.TundereBird/PopAccount.cs <==
using System;
using System.Net;

using Smdn.Net.Pop3;
using Smdn.Net.Pop3.Client;
using Smdn.Net.Pop3.WebClients;

namespace Smdn.Applications.TundereBird {
  public class PopAccount : AccountBase {
    protected override ICredentials Credentials {
      get { return credential; }
    }

    public bool UseTlsIfAvailable {
      get; private set;
    }

    public PopCapabilityList ServerCapabilities {
      get; private set;
    }

    public PopAccount(string name, Uri serverUri, ICredentials credential, int timeout, bool useTlsIfAvailable)
      : base(name, serverUri, timeout)
    {
      this.credential = credential;
      this.UseTlsIfAvailable = useTlsIfAvailable;
    }

    public PopWebRequest CreateRequest(Uri requestUri, string method)
    {
      return CreateWebRequest(requestUri, method) as PopWebRequest;
    }

    protected override void OnCreateRequest(WebRequest request)
    {
      var popRequest = request as PopWebRequest;

      popRequest.UseTlsIfAvailable = UseTlsIfAvailable;
      popRequest.DeleteAfterRetrieve = false;
    }

    public TResult Request<TResult>(Func<PopWebResponse, TResult> action)
    {
      return Request(null, null, action);
    }

    public TResult Request<TResult>(Uri requestUri, Func<PopWebResponse, TResult> action)
    {
      return Request(requestUri, null, action);
    }

    public TResult Request<TResult>(Uri requestUri, string method, Func<PopWebResponse, TResult> action)
    {
      using (var response = CreateRequest(requestUri, method).GetResponse() as PopWebResponse) {
        OnGotResponse(response);

        if (action != null)
          return action(response);
      }

      return default(TResult);
    }

    protected override void OnGotResponse(WebResponse response)
    {
      var r = response as PopWebResponse;

      if (!serverInfoRetrieved) {
        ServerCapabilities = r.ServerCapabilities;

        serverInfoRetrieved = true;
      }

      base.OnGotResponse(response);
    }

    private bool serverInfoRetrieved = false;
    private ICredentials credential;
  }
}

==> TundereBird-0.36.tar.bz2: TundereBird-0.36/gui/Smdn.Applications.TundereBird/Smdn.Applications.TundereBird/PopAccount.cs <==
using System;
using System.Net;

using Smdn.Net.Pop3;
using Smdn.Net.Pop3.Client;
using Smdn.Net.Pop3.WebClients;

namespace Smdn.Applications.TundereBird {
  public class PopAccount : AccountBase {
    protected override ICredentials Credentials {
      get { return credential; }
    }

    public bool UseTlsIfAvailable {
      get; private set;
    }

    public PopCapabilitySet ServerCapabilities {
      get; private set;
    }

    public PopAccount(string name, Uri serverUri, ICredentials credential, int timeout, bool useTlsIfAvailable)
      : base(name, serverUri, timeout)
    {
      this.credential = credential;
      this.UseTlsIfAvailable = useTlsIfAvailable;
    }

    public PopWebRequest CreateRequest(Uri requestUri, string method)
    {
      return CreateWebRequest(requestUri, method) as PopWebRequest;
    }

    protected override void OnCreateRequest(WebRequest request)
    {
      var popRequest = request as PopWebRequest;

      popRequest.UseTlsIfAvailable = UseTlsIfAvailable;
      popRequest.DeleteAfterRetrieve = false;
    }

    public TResult Request<TResult>(Func<PopWebResponse, TResult> action)
    {
      return Request(null, null, action);
    }

    public TResult Request<TResult>(Uri requestUri, Func<PopWebResponse, TResult> action)
    {
      return Request(requestUri, null, action);
    }

    public TResult Request<TResult>(Uri requestUri, string method, Func<PopWebResponse, TResult> action)
    {
      using (var response = CreateRequest(requestUri, method).GetResponse() as PopWebResponse) {
        OnGotResponse(response);

        if (action != null)
          return action(response);
      }

      return default(TResult);
    }

    protected override void OnGotResponse(WebResponse response)
    {
      var r = response as PopWebResponse;

      if (!serverInfoRetrieved) {
        ServerCapabilities = r.ServerCapabilities;

        serverInfoRetrieved = true;
      }

      base.OnGotResponse(response);
    }

    private bool serverInfoRetrieved = false;
    private ICredentials credential;
  }
}
